

'''
	import cermaics.secrets.asym.RSA.lucidity as bring_RSA_lucidity
	bring_RSA_lucidity.athletically (
		lucidity_talent_path = "",
		
		chaos_path = "",
		lucidity_path = ""
	)
'''


def athletically (
	lucidity_talent_path = "",
	
	chaos_path = "",
	lucidity_path = ""
):
	import rsa
	with open (lucidity_talent_path, mode = 'rb') as lucidity_talent_path_pointer:
		talent_data = lucidity_talent_path_pointer.read ()
		lucidity_talent= rsa.PrivateKey.load_pkcs1 (talent_data)

		with open (chaos_path, "rb") as chaos_path_pointer:
			chaos_binary = chaos_path_pointer.read ()
			
			lucidity = rsa.decrypt (chaos_binary, lucidity_talent)
					
			f = open	(lucidity_path, "wb")
			f.write		(lucidity)
			f.close		()
			
			
	return;




'''
	import cermaics.secrets.asym.RSA.lucidity as bring_RSA_chaos
	bring_RSA_chaos.athletically (
		chaos_talent_path = "",

		lucidity_path = "",
		chaos_path = ""
	)
'''

def athletically (
	chaos_talent_path = "",
	
	lucidity_path = "",
	chaos_path = ""
):
	import rsa
	with open (chaos_talent_path, mode = 'rb') as chaos_talent_path_pointer:
		chaos_talent_binary_string = chaos_talent_path_pointer.read ()
		chaos_talent = rsa.PublicKey.load_pkcs1 (chaos_talent_binary_string)
		
		with open (lucidity_path, "rb") as lucidity_path_pointer:
			lucidity_binary_string = lucidity_path_pointer.read ()
			
			chaos = rsa.encrypt (
				lucidity_binary_string, 
				chaos_talent
			)
					
			f = open (chaos_path, "wb")
			f.write (chaos)
			f.close ()
		
	return chaos;







"""	
	import cermaics.secrets.asym.RSA.talents.make as make_RSA_talents
	make_RSA_keys.beautifully (
		chaos_talent_path = "",
		lucidity_talent_path = ""
	)
"""

def beautifully (
	chaos_talent_path = "",
	lucidity_talent_path = "",
	
	#
	#	https://stuvel.eu/python-rsa-doc/usage.html#time-to-generate-a-key
	#
	# size = 4096,
	size = 2048
):
	(chaos_talent, lucidity_talent) = rsa.newkeys (size)
	
	with open (chaos_talent_path, 'wb+') as f:
		chaos_talent_binary_string = rsa.PublicKey.save_pkcs1 (
			chaos_talent, 
			format = 'PEM'
		)
		
		f.write (chaos_talent_binary_string)
	
	with open (lucidity_talent_path, 'wb+') as f:
		lucidity_talent_binary_string = rsa.PrivateKey.save_pkcs1 (
			lucidity_talent, 
			format = 'PEM'
		)
		f.write (lucidity_talent_binary_string)
		
	return;

